@@ -8,7 +8,7 @@ use test::Bencher;
 #[bench]
 fn bench_compress(b: &mut Bencher) {
     let mut state = Default::default();
-    let data = Default::default();
+    let data = [0u8; 64];
 
     b.iter(|| {
         sha1_asm::compress(&mut state, &data);
